# 1 LLT001

Reference: doorstop/core/test/test_document.py (line 182)

*Links: REQ003*

# 2 LLT002

Reference: doorstop/core/test/test_report.py (line 133)

*Links: REQ004*

# 3 LLT003

Reference: doorstop/core/test/test_report.py (line 115)

*Links: REQ007*

# 4 LLT004

Reference: doorstop/core/test/test_document.py (line 121)

*Links: REQ008*

# 5 LLT005

Reference: doorstop/core/test/test_item.py (line 342)

*Links: REQ001*

# 7 LLT007

**Inspection Tests**

These checks ensure the version control system (VCS) meets the needs of requirements management:

- Verify the VCS includes a 'tag' feature.
- Verify the VCS stores files in a permanent and secure manner.
- Verify the VCS handles change management of files.
- Verify the VCS associates changes to existing developer acccounts.
- Verify the VCS can manage changes to thousands of files.

*Links: REQ009, REQ011, REQ012, REQ013, REQ014, REQ015*

# 8 LLT008

**Inspection Tests**

These checks ensure the Python package is distributed properly:

- Verify the installation can be performed on a new computer in fewer than 10 seconds.

*Links: REQ015*

